@@ -13,8 +13,7 @@ from voluptuous import All, Any, Lower, Range, Coerce, Match
 
 from dvc.exceptions import DvcException
 from dvc.exceptions import NotDvcRepoError
-from dvc.utils.compat import open
-from dvc.utils.compat import str
+from dvc.utils.compat import open, str
 
 logger = logging.getLogger(__name__)
 
